# -*- coding: utf-8 -*-

from __future__ import unicode_literals
from .. import Provider as CompanyProvider


class Provider(CompanyProvider):

    company_names = [
        'گروه سیمان',
        'گروه فلزات اساسي',
        'ایران گچ',
        'آلومتك',
        'ساروج بوشهر',
        'آلومينيوم ايران',
        'سيمان  ساوه',
        'ایران ذوب',
        'سيمان اردبيل و آهك آذرشهر',
        'پارس مولیبدن',
        'سيمان اروميه',
        'ذوب روی اصفهان',
        'سيمان اصفهان',
        'صنايع مس شهيد باهنر',
        'سيمان ايلام',
        'صنایع خالص سازان روی زنجان',
        'سيمان بجنورد',
        'صنعتی و سرمایه گذاری سپنتا',
        'سيمان بهبهان',
        'كالسيمين',
        'سيمان تهران',
        'گروه كارخانه هاي توليدي نورد آلومينيوم',
        'سيمان خاش',
        'ملي سرب و روي ايران',
        'سيمان خزر',
        'ملی صنایع مس ایران',
        'سيمان داراب',
        'آلومراد',
        'سيمان دورود',
        'آلومينيوم المهدي',
        'سيمان سفيدني ريز',
        'آلومينيوم پارس',
        'سيمان شاهرود',
        'کارخانجات تولیدی مواد الومینیوم',
        'سيمان شرق',
        'مجتمع ذوب و احیای روی قشم',
        'سيمان شمال',
        'مجتمع صنايع الومينيوم جنوب',
        'سيمان صوفيان',
        'مس تکنار',
        'سيمان غرب',
        'گروه کانی های فلزی',
        'سيمان فارس',
        'آلوميناي ايران',
        'سيمان قاين',
        'تهيه و توليد مواد اوليه فولاد خراسان',
        'سيمان كارون',
        'سنگ آهن مركزي ايران',
        'سيمان كرمان',
        'هرمز انرژی',
        'سيمان مازندران',
        'واحد طلای موته',
        'سيمان هرمزگان',
        'واحد پیربکران',
        'سيمان هگمتان',
        'واحد فسفات اسفردی',
        'سیمان خوزستان',
        'واحد نخلک',
        'سیمان دشتستان',
        'ويتانا',
        'سیمان زابل',
        'گروه صنایع غذایی',
        'سیمان فارس نو',
        'کشاورزی و تحقیقاتی نوین زعفران',
        'سیمان لار سبزوار',
        'گلستان',
        'سیمان لارستان',
        'آرد زر',
        'سیمان لامرد',
        'اروم آدا',
        'سیمان مجد خواف',
        'ایران گلاب مرغوب',
        'سیمان ممتازان کرمان',
        'بيسكوئيت گرجي',
        'فراورده سیمان شرق',
        'تحول چاشنی توس',
        'گچ ماشيني فارس',
        'تهیه و بسته بندی خشکبار آرات',
        'سیمان آذر آبادگان خوی',
        'توسعه کشت ذرت',
        'سیمان بوهروک یزد',
        'تولیدی آرد البرز',
        'سیمان جوین',
        'تولیدی زعفران سحرخیز',
        'سیمان قشم',
        'خوراك دام پارس',
        'سیمان کردستان',
        'دشت مرغاب',
        'گچ تهران',
        'روغن نباتي پارس',
        'گروه فولاد',
        'روغن نباتي جهان',
        'پلی ران اتصال',
        'روغن نباتی گلناز',
        'توليدی لوله هاي پلي اتيلن دوجداره بوشهر',
        'روغنکشی خرمشهر',
        'تولید لوله و پوشش سلفچگان',
        'زر ماکارون',
        'سلفچگان',
        'سالمين',
        'ذوب آهن اصفهان',
        'سپتیکو',
        'ساخته های فلزی اصفهان',
        'سحر همدان',
        'صنايع فرو آلياژ ايران',
        'سقزسازی کردستان',
        'صنايع گالوانيزه فجر سپاهان',
        'شاد گل نیشابور',
        'صنایع فولاد آلياژي يزد',
        'شهد ايران',
        'فولاد اکسین خوزستان',
        'صنایع غذایی مینو شرق',
        'فولاد آلیاژی ایران',
        'صنعتي  پارس مينو',
        'فولاد خوزستان',
        'صنعتي مينو خرم دره',
        'فولاد صنعت مهدی',
        'فراورده های سیب زمینی پریس اصفهان',
        'فولاد مباركه اصفهان',
        'فرآورده های گوشتی تهران',
        'کارخانجات نورد لوله یاران',
        'كشت و صنعت پياذر',
        'کاوه کشاورز',
        'كيوان',
        'گروه صنعتي سپاهان',
        'کشت و صنعت اشراق',
        'لوله و پروفیل سپنتا تهران',
        'کشت و صنعت قطران گل ایران',
        'لوله و ماشين سازي ايران',
        'کشت وصنعت روژین تاک',
        'مجتمع فولاد خراسان',
        'کشتارگاه صنعتی طیور سپیدان آمل',
        'میراب پروفیل',
        'گروه توليدي مهرام',
        'نورد و توليد قطعات فولادي',
        'گلوكوزان',
        'نورد و لوله صفا',
        'مارگارين',
        'نوین آلیاژسمنان',
        'مجتمع صنایع غذایی بهپودر اصفهان',
        'فولاد آذربايجان',
        'مجتمع كشت و صنعت چين چين',
        'فولاد افزا سپاهان',
        'مجتمع کارخانجات سوربن شمال',
        'گروه ملي صنعتي فولاد ايران',
        'مرغ اجداد زربال',
        'پروفيل صنعت جنوب',
        'شوكو پارس',
        'صبا فولاد خلیج فارس',
        'آرد تجارت',
        'فولاد تربت حیدریه',
        'بهپاك',
        'لوله و تجهيزات سديد',
        'پيچك',
        'نورد لوله اهواز',
        'توسعه کشت و صنعت ملی ( كشت و صنعت گرگان )',
        'نورد و پروفيل پارس',
        'فراورده هاي غذائي مشهد',
        'گروه پیمانکاری صنعتی',
        'گروه معادن',
        'احداث صنعت',
        'معدن کاران انگوران',
        'گروه ساخت قطعات خودرو',
        'باما',
        'تولید موتور های دیزل ایران',
        'تامين ماسه ريخته گري',
        'اگزوز خودرو خراسان',
        'تامین مواد اولیه فولاد صبا نور',
        'الكتريك خودرو شرق',
        'توسعه معادن روي ايران',
        'آهنگري تراكتورسازي ايران',
        'توليد فروموليبدن كرمان',
        'اورند پلاستیک',
        'تولیدی آذر سنگ سرخ',
        'ايران دوچرخ',
        'جهاد نصر سیرجان',
        'پلاسكو كار سايپا',
        'حفاری ایراندشت کاشان',
        'توليد محورخودرو',
        'ذوب وروی بافق',
        'توليدي قطعات محوري خراسان',
        'زرین معدن آسیا',
        'تولیدی صنعتی لنت پارس',
        'زغال سنگ نگين طبس',
        'چرخشگر',
        'زنجان برنز',
        'رادياتور ايران',
        'سرمایه گذاری توسعه معادن کوثر',
        'ريخته گري تراكتورسازي ايران',
        'سنگ آهن شرق',
        'رينگ سازي مشهد',
        'سنگ آهن گل گهر',
        'ریخته گری آلومینیوم ایران خودرو',
        'سنگاب آذرشهر',
        'ساخت و نصب صنعتی البرز',
        'سنگاب همدان',
        'سازه پويش',
        'سوژميران',
        'سايپا آذين',
        'سولفاتيک',
        'سایپا پرس',
        'شن سازان هراز',
        'سیبا موتور',
        'صنعت روی زنگان',
        'شمیم پژوهش',
        'صنعتي و معدني شمال شرق شاهرود',
        'صنايع ريخته گري ايران',
        'فراوري مواد معدني ايران',
        'صنایع ریخته گری پرلیت آسیا',
        'فرو سيليس ايران',
        'صنایع نوید موتور',
        'مجتمع معادن سنگ چینی نی ریز',
        'صنعتي نيرو محركه',
        'معادن بافق',
        'صنعتی صبوران پلیمر',
        'معادن سنگ اهن احیاء سپاهان',
        'فنر سازی زر گلپايگان',
        'معادن منگنز ايران',
        'فنرسازي خاور',
        'معدن کار باختر',
        'فنرسازي زر',
        'معدني دماوند',
        'كاربراتور ايران',
        'معدني و صنعتي چادرملو',
        'كارخانجات كمك فنر ايندامين سايپا',
        'معدنی و فرآوری سرمه فیروزآباد',
        'کابل خودرو سبزوار',
        'ندای رهاوی',
        'کلاچ سازی شایان صنعت',
        'زغال سنگ البرز شرقی',
        'گیربکس سایپا',
        'زغال سنگ البرز مرکزی',
        'لنت ترمز ايران',
        'زغال سنگ کرمان',
        'ماشین سازی فراگیر سپنتا',
        'فرآوري معدني اپال کاني پارس',
        'مجتمع صنعتی سپاهان باطری',
        'گروه توسعه معادن روی ایران',
        'محورسازان ايران خودرو',
        'گروه قند و شکر',
        'مهركام پارس',
        'سهامی عام شهد – قند خوی',
        'مهندسي نصير ماشين',
        'شکر شاهرود',
        'موتورسازان تراكتورسازي ايران',
        'صنعتی کشاورزی شیرین خراسان',
        'نیروسازاراک‎',
        'فرآورد ه هاي غذايي و قند پيرانشهر',
        'یسکو',
        'فراورده هاي غذايي و قند تربت جام',
        'گروه انتشار، چاپ و تكثير',
        'فرآورده هاي غذايي و قند چهارمحال',
        'افست',
        'قند اصفهان',
        'گروه خدمات فنی و مهندسی',
        'قند ثابت خراسان',
        'ملی ساختمان',
        'قند شيروان قوچان وبجنورد',
        'مهندسی فرا نیرو',
        'قند قهستان',
        'آبادراهان پارس',
        'قند لرستان',
        'احداث تاسیسات انتقال نیرو – اتانیر',
        'قند مرودشت',
        'آذرپاسیلو',
        'قند نقش جهان',
        'ارسا ساختمان',
        'قند نيشابور',
        'آفرینه طوس',
        'قند هكمتان',
        'اهرام فناوری قدرت',
        'کارخانجات قند قزوین',
        'ایریتک',
        'قند بيستون',
        'بازرسي مهندسي و صنعتي ايران',
        'قند پارس',
        'تجهیزات و خدمات صنایع آب و برق ایران – صانیر',
        'گروه رایانه و فعالیتهای وابسته به آن',
        'تکنیک',
        'ایران ارقام',
        'توسعه ساخت و نصب صنايع بتني و فلزي گسترش مانا ساز آبيک',
        'تجارت الكترونيك پارسيان',
        'جنرال مکانیک',
        'توسعه سازه پایه فن آوا',
        'حفاری شمال',
        'توسعه فناوری اطلاعات خوارزمی',
        'خدمات مهندسی ساختمان تاسیسات راه آهن',
        'تینا سامانه',
        'خدماتي تجهيزات سنگين همگام',
        'داده پردازي خوارزمي',
        'راهبران فولاد اصفهان',
        'داده پردازی ایران',
        'راهسازی و ساختمانی 115',
        'داده پردازی فن آوا',
        'ره  گستر نفت',
        'داده سامانه فن آوا',
        'صنعتی دریایی ایران – صدرا',
        'فن آوا کارت',
        'فراب',
        'کارت اعتباری ایران کیش',
        'کیسون',
        'گسترش الکترونیک مبین ایران',
        'معماران پارس صنعت',
        'خدمات انفورماتیک',
        'مهام شرق',
        'گروه وسايل اندازه گيري، پزشكي و اپتيكي',
        'مهندسان مشاور سازه',
        'مهندسی فرسار تجارت',
        'مهندسي و نصب فيرمکو پارس',
        'پویندگان راه سعادت',
        'مهندسي وتحقيقاتي فلزات غيرآهنی',
        'كنتور سازي ايران',
        'مهندسی و پشتیبانی نیروگاهی البرز توربین',
        'گروه ماشين آلات و تجهيزات',
        'موننکو ایران',
        'مارال صنعت جاوید',
        'نصب نیرو',
        'ماشین رول',
        'خدمات ماشینی کشتیرانی',
        'افرند کالا سازه',
        'گسترش صنايع وخدمات',
        'آلفا پاک ایران',
        'گروه لوازم خانگي',
        'بلبرينگ ايران',
        'لعران',
        'بهسازان غلطک فولاد اصفهان',
        'ارج',
        'پارس بوشونگ',
        'آیسان خزر',
        'پاریزان صنعت',
        'پارس خزر',
        'پمپ سمنان انرژی',
        'تولیدی و صنعتی نیک کالا',
        'تراكتور سازي ايران',
        'صنايع سرماآفرين قشم',
        'تراکتور سازی کردستان',
        'صنعتي جنرال',
        'تسهیل ماشین صنعت',
        'كارخانجات آبسال',
        'توليد تجهيزات سنگين هپكو',
        'كارخانجات لوازم خانگي پارس',
        'توليدي پمپ پارس',
        'کارخانجات پارس ماشین',
        'توليدي تجهيزات ايمني راهها',
        'گروه صنعتي بوتان',
        'تیراژه ماشین',
        'لوازم خانگی نانیوا',
        'دلتا راه ماشین',
        'توليدي كولر گازي ايران',
        'رهشاد سپاهان',
        'جام جهان نما',
        'ساخت تجهيزات سپاهان',
        'كارخانجات صنعتي آزمايش',
        'سوت ماشین',
        'گروه پلاستيك',
        'صنايع پمپ سازي ايران',
        'یزد بسپار',
        'صنايع سرما آفرين',
        'آرتا پلاست',
        'صنایع پمپ ابارا',
        'پلاستيران',
        'صنعتی هلی خودرو',
        'پلاستيکهاي مهندسي درخشان ساز',
        'طراحي مهندسي وساخت تجهيزات وابزارآلات سايپا',
        'توليدي پلاستيك شاهين',
        'فولادريزي قائم سپهر سپاهان',
        'توليدي گاز لوله',
        'کالای پمپ',
        'توليدي و صنعتي درخشان تهران',
        'ماشين سازي اراك',
        'جوی گستر نفت',
        'ماشين سازي نیرو محركه',
        'صنايع لاستيك سهند',
        'مهندسي تكنو تار',
        'كارخانجات توليدي تهران',
        'مهندسي و توليد ماشين آلات راهسازي و معدني کشاورزي هپکو اراک',
        'توليدي وصنعتي ايران وغرب',
        'مهندسي و ساختمان ماشين سازي اراک',
        'لوله سازي اهواز',
        'مهندسي و قطعات ماشين آلات راه سازي ايران',
        'گروه مبلمان و مصنوعات ديگر',
        'مهندسی فیروزا',
        'عايق پلاستيك',
        'مهندسی و ساخت بویلر مپنا',
        'تجهيزات مدارس ايران',
        'هوا ابزار تهران',
        'صنعتی جهان چیدمان-جلیس',
        'اشتهاد موتورز',
        'گروه محصولات شيميايي',
        'كارخانجات صنعتي  و توليدي اتمسفر',
        'احسان شیمی استهبان',
        'كمپر سور سازي ايران',
        'آریا رزین',
        'ليفتراك سازي سهند',
        'الکترو زر سازه',
        'فرتاک ماشین',
        'ایمن تاش سپاهان',
        'کمباین سازی ایران',
        'بردار شیب',
        'ماشين آلات صنعتي تراكتور سازي ايران',
        'بين المللي محصولات پارس',
        'صنايع توليدي اشتاد ايران',
        'بين المللي سارنگ تدارك',
        'پروفيل و يخچال ايران پويا',
        'پارس زئولايت',
        'توليدي بهمن',
        'پارسیان پارت پاسارگاد',
        'گروه محصولات كاغذي',
        'پاكسان',
        'بسته بندي پارس',
        'پاکنام',
        'صنايع كاغذ سازي كاوه',
        'پالایش قطران ذغالسنگ اصفهان',
        'صنایع چوب و کاغذ مازندران',
        'توکا رنگ فولاد سپاهان',
        'كارتن البرز',
        'تولي پرس',
        'كارتن ايران',
        'توليد سموم علف كش',
        'کارتن مشهد',
        'تولید مواد اولیه الیاف مصنوعی',
        'محصولات کاغذی لطیف',
        'تولیدی و صنعتی  فراسان',
        'كارتن پارس',
        'تولیدی و صنعتی سامد',
        'گروه منسوجات',
        'تولیدی وصنعتی خودرنگ',
        'ايران برك',
        'حباب کف توس',
        'توليدي بافت آزادي',
        'داروئي ارايشي وبهداشتي مينو',
        'وطن اصفهان',
        'دنیای آرایش',
        'ريسندگي و با فندگي كاشان',
        'دوده صنعتي پارس',
        'ريسندگي و بافندگي پاكريس',
        'رزیتان',
        'ريسندگي و بافندگي ري',
        'ریف ایران',
        'فرش پارس',
        'سامان شیمی',
        'گردباف يزد',
        'سرمايه گذاري صنايع شيميايي ايران',
        'گروه صنعتي نقش ايران',
        'شيمي بافت',
        'نساجي بابكان',
        'شيميايي پارس پامچال',
        'نساجي خوي',
        'شيميايي فرآورد قشم',
        'نساجي غرب',
        'شیمیایی بهداد',
        'نساجي قائم شهر',
        'شیمیایی بهداش',
        'نساجي مازندران',
        'شیمیایی و تولیدی رزپلیمر',
        'وطن اصفهان',
        'صنايع شيميايي رنگين',
        'يزد باف',
        'صنايع شيميايي سينا',
        'صنايع نساجي ايران',
        'صنايع شيميايي فارس',
        'گروه بانك ها، موسسات اعتباري و ساير نهادهاي مالي',
        'صنایع بهداشتی ساینا',
        'بانك اقتصاد نوين',
        'صنایع رنگ و رزین طیف سایپا',
        'بانك پارسيان',
        'صنایع شیمی ساختمان آباد گران',
        'بانك سامان',
        'فراپاکس شیراز',
        'بانك كارآفرين',
        'كربن ايران',
        'بانک انصار',
        'كف',
        'بانک ایران زمین',
        'کلر پارس',
        'بانک پاسارگاد',
        'گلتاش',
        'بانک تجارت ایران',
        'لابراتوارهای داروهای گیاهی طبیعت زنده',
        'بانک حکمت ایرانیان',
        'لعاب مشهد',
        'بانک دی',
        'لعابيران',
        'بانک سرمایه',
        'مجتمع صنایع شیمیایی پلیمر ایران',
        'بانک سینا',
        'مديريت صنعت شوينده توسعه صنايع بهشهر',
        'بانک شهر',
        'مروارید هامون',
        'بانک صادرات ایران',
        'معدني املاح ايران',
        'بانک گردشگری',
        'ملي شيمي كشاورز',
        'بانک ملت',
        'من',
        'پست بانک',
        'نيرو كلر',
        'بانک تات',
        'الياف',
        'بانک کشاورزی',
        'پارسيلون',
        'گروه واسطه گري هاي مالي',
        'توليدي  الياف پلي  پروپيلين  بنياد',
        'رايان سايپا',
        'صنايع تبديلي گلستان',
        'سپرده گذاری مرکزی اوراق بهادار و تسویه وجوه',
        'كارخانجات توليدي سوپر رنگ',
        'ليزينگ آريادانا',
        'صنايع رنگ پارس الوان',
        'ليزينگ ايران',
        'گروه مواد و محصولات دارويي',
        'ليزينگ خودرو غدير',
        'آفا شیمی',
        'ليزينگ صنعت و معدن',
        'البرز دارو',
        'ليزينگ ماشين الات سنگين ايرانيان',
        'ايران دارو',
        'لیزینگ اقتصاد نوین',
        'پارس دارو',
        'لیزینگ رازی',
        'تحقیقاتی و تولیدی سیناژن',
        'لیزینگ ماشین آلات و تجهیزات پاسارگاد',
        'تهران دارو',
        'لیزینگ ایرانیان',
        'تهران شيمي',
        'لیزینگ شهر – لیزینگ سامان آریا',
        'توليد ژلاتين کپسول ايران',
        'گروه توزیع برق',
        'توليد مواد اوليه دارو پخش',
        'توزیع برق بوشهر',
        'تولید مواد دارویی درسا دارو',
        'توسعه برق شمال افشان گستر',
        'داروسازي اسوه',
        'صنايع برق زنگان پارس',
        'داروسازي اكسير',
        'گهر انرژي سيرجان',
        'داروسازي امين',
        'برق و انرژی صبا',
        'داروسازي جابرابن حيان',
        'گروه شرکتهای بازرگانی',
        'داروسازي حكيم',
        'اتصال استیل هما',
        'داروسازي دكتر عبيدي',
        'اسپرلوس اهورا',
        'داروسازي روزدارو',
        'افزار پرداز رمیس',
        'داروسازي زهراوي',
        'الهام بیسان',
        'داروسازي فارابي',
        'ایمان تجارت روشن',
        'داروسازي كوثر',
        'بازرگاني پتروشيمي',
        'داروسازی بهوزان',
        'بازرگانی ارمغان مهر سیرت',
        'داروسازی تولید دارو – سهامی خاص',
        'بازرگانی ایران ترانسفو',
        'داروسازی دانا',
        'بازرگانی بین المللی استوان سپند',
        'داروسازی شهید قاضی تبریز',
        'بازرگانی پارس ماهان آسیا',
        'داروسازی گیلارانکو',
        'بازرگانی پتروشیمی زنجان',
        'داروئي و بهداشتي لقمان',
        'بازرگانی تبادل و تدارک کالا',
        'داملران',
        'بازرگانی صبا بیمه ایرانیان',
        'سينا دارو',
        'بازرگانی مبین تجارت غرب',
        'شيمي دارويي داروپخش',
        'بازرگانی نفت یاب',
        'صنعتي كيميدارو',
        'بازرگانی،صنعتی بهشت پارس',
        'فارما شیمی',
        'بهترین های پزشکی پارس',
        'فراورده هاي تزريقي ايران',
        'پارس بازرگان',
        'كارخانجات دارو پخش',
        'پارس گستر مینو',
        'لابراتورهای دارویی رازک',
        'پديده گستران غرب',
        'مواد اولیه دارویی تهران شیمی',
        'تجارت گستران خوارزمي',
        'داروسازی سبحان انکولوژی',
        'تجاری و بازرگانی مواد معدنی میناب',
        'سرمايه گذاري البرز',
        'تجهیز یاران',
        'شيرين دارو',
        'تهیه و تولید خاک نسوز استقلال آباده',
        'گروه دارویی سبحان',
        'توسعه صنايع غذايي بم',
        'گروه خودروسازی',
        'توسعه و تجارت بین المللی صبا',
        'ايران خودرو',
        'توسعه و تجارت ماتریس',
        'ايران خودروديزل',
        'جهان فعالیت',
        'ایران خودرو تبریز',
        'خشکبار دست چین',
        'ایران خودرو خراسان',
        'داده های رسا',
        'ایران خودرو مازندران',
        'دانیال کار',
        'بهمن دیزل',
        'درمان یار آنی',
        'پارس خودرو',
        'راسن درمان',
        'تولیدی و صنعتی عقاب افشان',
        'رویال پیشگام شرق',
        'زامياد',
        'سامان بارز',
        'سايپا',
        'سیاحان سپهر آسیا',
        'سايپاديزل',
        'صخره سنگی فرزین',
        'سایپا کاشان',
        'صنایع نئون پرس',
        'گروه بهمن',
        'فانوس دشت تجارت',
        'بنيان ديزل',
        'کیا مهستان',
        'توليدي مرتب',
        'کیمیا آرا هرم',
        'گروه محصولات لبني',
        'گسترش تجارت کالای ایرانیان',
        'پاک پی',
        'مديريت و ساخت طرحهاي نفت گستر',
        'تولید فرآورده های لبنی کاله',
        'مهر اسپند پویا',
        'شير پاستوريزه پگاه اصفهان',
        'مهندسی بازرگانی درداران سریر',
        'شير پاستوريزه پگاه خراسان',
        'نویان بسپار',
        'شير پگاه آذربايجان غربي',
        'نیکان شهد بارز',
        'صنايع شير ايلام زاگرس',
        'گروه هولدینگ',
        'فراورده هاي لبني پاکسار ساري',
        'توسعه صنايع بهشهر – هلدينگ',
        'لبنيات پاستوريزه پاك',
        'داروپخش – هلدينگ',
        'لبنيات كالبر',
        'راه آهن جمهوری اسلامی ایران',
        'لبنیات پاستوریزه پاک آرا سنندج',
        'سرمايه گذاري توسعه معادن و فلزات',
        'گروه منسوجات و فرش بافی',
        'سرمايه گذاري توكا فولاد – هلدينگ',
        'ابهر ریس',
        'سرمايه گذاري صنعت نفت – هلدينگ',
        'ايران پوپلين',
        'سرمایه گذاری گروه صنعتی ملی',
        'ايران مرينوس',
        'گروه صنعتي سديد – هلدينگ',
        'بافتینه',
        'گروه صنعتي قطعات اتومبيل ايران',
        'پشمبافي توس',
        'گروه صنعتي ناب',
        'پلي اكريل ايران',
        'گسترش نفت و گاز پارسیان',
        'تمدن فرش کاشان',
        'مدیریت پروژه های نیروگاهی ایران – مپنا',
        'تولیدی پارس دکور',
        'هلدینگ توسعه معادن و صنایع معدنی خاورمیانه',
        'تولیدی پارس نخ',
        'هلدینگ دامپروری شیروگوشت پارس',
        'تولیدی پینک',
        'سرمايه گذاري بانك ملي ايران – هلدينگ',
        'تولیدی و صنعتی پارس تکمیل',
        'صنعتي بهشهر',
        'تولیدی و صنعتی رسول اصفهان',
        'گروه بنادر ودریانوردی',
        'شبنم باف',
        'پایانه ها و مخازن پتروشیمی',
        'صنایع موکت همدان',
        'خدمات دریایی و بندری کاوه',
        'صنایع نخ خمین',
        'گروه گاز',
        'صنایع نساجی همدانیان',
        'گاز اصفهان',
        'ظریف مصور',
        'ملی گاز',
        'فرش مشهد',
        'گاز خراسان جنوبی',
        'فرش نگین مشهد',
        'گروه آشامیدنی ها',
        'کارخانجات ریسندگی نطنز',
        'آب معدنی دماوند',
        'مخمل و ابريشم كاشان',
        'آذر شهد ارومیه',
        'موکت نگین مشهد',
        'بهنوش ايران',
        'نساجي بروجرد',
        'پیمان فردان',
        'نساجی کویر سمنان',
        'تولیدی نوشابه ارم نوش',
        'صنايع نساجي ايران',
        'زمزم آذربایجان',
        'گروه حمل و نقل دریایی و حمل و نقل آب های ساحلی',
        'زمزم اصفهان',
        'حمل و نقل ترکیبی کشتیرانی جمهوری اسلامی',
        'زمزم تهران',
        'حمل و نقل خدمات دریایی آبادان',
        'زمزم رشت',
        'خدمات دریایی و کشتیرانی خط دریا بندر',
        'زمزم گرگان',
        'دريابان جنوب ايران',
        'شهداب',
        'کشتیرانی آریا',
        'فرآورده های نوشیدنی تسنیم نوش',
        'کشتیرانی جمهوری اسلامی ایران',
        'نوش مازندران',
        'کشتیرانی والفجر',
        'ساسان',
        'گروه خدمات فنی-مهندسی خودرو',
        'گروه تایر سازی',
        'امداد خودرو ایران',
        'ایران یاسا',
        'امداد خودرو سایپا',
        'بید وایر ایران',
        'بازرسی فنی و کنترل خوردگی تکین کو',
        'توليدي ايران تاير',
        'گواه',
        'توليدي لاستيکهاي صنعتي مبارکه',
        'مزدا یدک',
        'کویر تایر',
        'مهندسی و مشاور سازه گستر سایپا',
        'لاستيك دنا',
        'خدمات کمات ماشین شرق',
        'لاستیک بارز',
        'گروه فرهنگی و گردشگری',
        '8',
        'لاستیک پارس',
        'تجارت توسعه گردشگري آتيه انديشان',
        'مجتمع صنايع لاستيك يزد',
        'توسعه گردشگري کاروانسراي پارس',
        'مجتمع صنعتي آرتاويل تاير',
        'گروه سرمايه گذاري ميراث فرهنگي و گردشگري ايران',
        'توليدي لاستيك البرز – كيان تاير',
        'مجتمع توريستي، رفاهي آبادگران ايران',
        'گروه شرکتهای مشاوره',
        'گروه كاني های غير فلزي',
        'irpmc',
        'آجر نسوز امين آباد',
        'بودجه irpmc',
        'آذريت',
        'همکاران سیستم اردبیل',
        'ايتالران',
        'همکاران سیستم البرز',
        'ايرانيت',
        'همکاران سیستم پناه شرق',
        'پرمیت',
        'همکاران سیستم خراسان جنوبی',
        'پشم شیشه ایران',
        '7',
        'همکاران سیستم خراسان رضوی',
        'تولیدی و صنعتی آبگینه',
        'همکاران سیستم خوزستان',
        'خاك چيني ايران',
        'همکاران سیستم زنجان',
        'زرین شیشه مرکزی',
        'همکاران سیستم فارس',
        'سایپا شیشه',
        'همکاران سیستم قزوین',
        'سراميك هاي صنعتي اردكان',
        'همکاران سیستم گیلان',
        'شيشه قزوين',
        'همکاران سیستم مازندران',
        'شيشه همدان',
        'گروه ماشين آلات و دستگاههاي برقي',
        'شيشه و گاز',
        'ايران ترانسفو',
        'شیشه داروئی رازی تاکستان',
        'ایران ترانسفوی ری',
        'فارسيت اهواز',
        'پارس سوئيچ',
        'فرآورده هاي نسوز پارس',
        'تال ایران',
        'فرآورده هاي نسوزآذر',
        'تامین تابلو',
        'فراورده های نسوز ایران',
        'تجهیزات انتقال برق پارس',
        'كارخانجات توليدي شيشه دارويي رازي',
        'ترانسفور ماتور توزیع زنگان',
        'كارخانه فارسيت درود',
        'تهران پادنا',
        'ورزيران',
        'توربوژنراتور شاهرود',
        'مقره سازی ایران',
        'توس فیوز',
        'چینی سازی البرز',
        'جابون',
        'گروه ارتباطات',
        'خیام الکتریک',
        'ارتباطات فن آوا',
        'صنايع جوشكاب يزد',
        'ارتباطات کوه نور',
        'صنایع کابل سازی افق البرز',
        'ارتباطات سیار ایران – همراه اول',
        'صنعتی مهندسی پالایش نیرو',
        'مخابرات ایران',
        'فاراتل',
        'گروه شرکت های پخش',
        'كابل البرز',
        'پخش سراسری کالای کالبر',
        'كابل باختر',
        'پخش هجرت',
        'كابلهاي مخابراتي شهيد قندي',
        'توزيع داروهاي دامي داروپخش',
        'كارخانجات كابلسازي ايران',
        'مهندسي و پشتيباني پخش فرآورده هاي نفتي امين',
        'کابل تک',
        'گروه بیمه',
        'لامپ پارس شهاب',
        'بيمه پاسارگاد',
        'مازی نور',
        'بیمه آسیا',
        'مهندسی مپنا مکو',
        'بیمه البرز',
        'مهندسی و ساخت توربین مپنا توکا',
        'بیمه پارسیان',
        'مهندسی و ساخت ژنراتور مپنا – پارس',
        'بیمه دانا',
        'موتوژن',
        'بیمه دی',
        'نيرو ترانس',
        'بیمه نوین',
        'پارس نور الکتریک',
        'صندوق بیمه سرمایه گذاری فعالیت های معدنی',
        'توليدي قوه پارس',
        'گروه سرمايه گذاري ها',
        'مهندسی و ساخت پره توربين مپنا – پرتو',
        'حفیظ سامانه',
        'تامین قطعات و تجهیزات سرو نیرو شیراز',
        'تکادو',
        'صنایع مهتاب خراسان',
        'سرمايه گذاري آتيه دماوند',
        'صنعتي مهر آباد',
        'سرمايه گذاري انديشه محوران',
        'گروه كشاورزي ، دامپروري و خدمات وابسته به آن',
        'سرمايه گذاري بهمن',
        'تلیسه نمونه',
        'سرمايه گذاري پارس توشه',
        'دانه چین',
        'سرمايه گذاري توسعه آذربايجان',
        'دامپروری و مرغداری دشت خرمدره',
        'سرمايه گذاري توسعه صنعتي ايران',
        'دامداری شیر و دام بنیاد',
        'سرمايه گذاري توسعه ملي',
        'شیر و گوشت زاگرس',
        'سرمايه گذاري چشم انداز توسعه شمال',
        'کشاورزی ودامپروری بینالود',
        'سرمايه گذاري ساختمان ايران – هلدينگ',
        'کشاورزی ودامپروری دشت نوین ملایرا',
        'سرمايه گذاري سايپا',
        'کشاورزی ودامپروری یاسوج',
        'سرمايه گذاري سپه',
        'کشت و دام قیام اصفهان',
        'سرمايه گذاري صندوق بازنشستگي كشوري',
        'کشت وصنعت سبز پاسارگاد',
        'سرمايه گذاري صنعت بيمه',
        'گسترش صنايع و خدمات کشاورزي',
        'سرمايه گذاري صنعت ومعدن',
        'مجتمع دامداری بیجین',
        'سرمايه گذاري گروه صنايع بهشهر ايران',
        'مجتمع شیر و گوشت مهدشت',
        'سرمايه گذاري گروه صنعتي رنا',
        'مگسال',
        'سرمايه گذاري معيار صنعت پارس',
        'کشت وصنعت پیوند هراز',
        'سرمايه گذاري ملت',
        'گروه محصولات فلزي',
        'سرمايه گذاري ملي ايران',
        'صنعتی گام اراک',
        'سرمايه گذاري نيرو',
        'آریا بارون توس',
        'سرمايه گذاري هامون کيش',
        'پودر جوش ایران',
        'سرمایه گذاری اعتماد جم',
        'تولیدی و صنعتی الکترود یزد',
        'سرمایه گذاری اقتصاد نوین',
        'جوش و اکسیژن ایران',
        'سرمایه گذاری ایساتیس پویا',
        'دژپاد',
        'سرمایه گذاری پارس آریان',
        'سولیران',
        'سرمایه گذاری توسعه و عمران استان اردبیل-سبلان سبز',
        'صنايع مفتولي زنجان',
        'سرمایه گذاری دارویی تامین',
        'صنایع آذرآب',
        'سرمایه گذاری دانایان پارس',
        'صنایع استیل البرز',
        'سرمایه گذاری سروش یاران',
        'صنایع بسته بندی ایران',
        'سرمایه گذاری صندوق بازنشستگی کارکنان بانک ها',
        'صنایع بسته بندی مشهد',
        'گسترش سرمايه گذاري ايران خودرو',
        'صنایع فلزی کوشا',
        'گسترش سرمایه گذاری ایرانیان',
        'صنعتی آما',
        'مديريت سرمايه گذاري اميد',
        'صنعتی جام دارو',
        'نیرو سرمایه',
        'لامیران – تیغ ایران',
        'هلدینگ توسعه معادن و صنایع معدنی خاور میانه -میدکو',
        'آونگان',
        'ملی نفت ایران',
        'پارس متال',
        'مديريت سرمايه برنا',
        'پایساز',
        'سرمايه گذاري بوعلي',
        'توسعه و گسترش صنایع بسته بندی فلزی',
        'سرمايه گذاري سمند',
        'تولیدی ابزار مهدی',
        'سرمايه گذاري صنايع پتروشيمي',
        'گسترش صنایع انرژی آذرآب',
        'سرمايه گذاري كار آفرين',
        'صنایع فلزی ایران',
        'سرمايه گذاري نفت قشم',
        'صنعتی کاوه',
        'سرمایه گذاری پویا همگام',
        'صنعتی ملایر',
        'سرمایه گذاری توسعه  الوند غدیر',
        'بسته بندي البرز',
        'گروه فعاليتهاي پشتيباني و حمل و نقل',
        'گروه حمل و نقل، انبارداری و ارتباطات',
        'خدمات دريايي تايدواترخاورميانه',
        'بنیادبارانداز',
        'گروه توليدات پتروشيمي',
        'توکا ریل',
        'پترو شیمی لاله',
        'حمل و نقل آشنا راه سماء',
        'پتروشيمي آبادان',
        'حمل و نقل بین المللی خلیج فارس',
        'پتروشيمي اراك-پتروشیمی شازند',
        'حمل و نقل پتروشیمی',
        'پتروشيمي اصفهان',
        'حمل و نقل توکا',
        'پتروشيمي شيراز',
        'گروه فرآورده هاي نفتي كك و سوخت هسته اي',
        'پتروشیمی  پردیس',
        'پالايشگاه نفت تبريز',
        'پتروشیمی  زاگرس',
        'پالایش نفت آبادان',
        'پتروشیمی امیرکبیر',
        'پالایش نفت بندر عباس',
        'پتروشیمی بندر امام',
        'پالایش نفت تهران',
        'پتروشیمی بیستون',
        'پالایش نفت لاوان',
        'پتروشیمی تند گویان',
        'پالایشگاه نفت شیراز',
        'پتروشیمی جم',
        'تجهيز نيروي زنگان',
        'پتروشیمی جهرم',
        'خدمات حفاری صنایع نفت',
        'پتروشیمی خارک',
        'نفت ایرانول',
        'پتروشیمی خراسان',
        'نفت بهران',
        'پتروشیمی رجال',
        'نفت پارس',
        'پتروشیمی فن آوران',
        'نگین فخر آذربایجان',
        'پتروشیمی مارون',
        'توسعه نفت وگاز مپنا',
        'پتروشیمی مبین',
        'تولیدی مخازن گاز طبیعی آسیا ناما',
        'صنایع پتروشیمی کرمانشاه',
        'گروه كاشي و سراميك',
        'پتروشيمي اروند',
        'پارس سرام',
        'پتروشيمي برزويه',
        'تولید سرام دیر گداز',
        'پتروشيمي فجر',
        'تولیدی توس چینی',
        'مديريت توسعه صنايع پتروشيمي',
        'تولیدی گرانیت بهسرام',
        'پتروشيمي بوعلي سينا',
        'سرامیک طوس',
        'پتروشيمي بين الملل',
        'صنایع چینی زرین ایران',
        'پتروشيمي خوزستان',
        'صنایع کاشی اصفهان',
        'پتروشيمي پارس',
        'صنایع کاشی تیما',
        'اوره و ؛آمونیک پتروشیمی زنجان',
        'صنایع کاشی نائین',
        'پتروشيمي فسا',
        'صنایع کاشی و سرامیک الوند',
        'پتروشیمی داراب',
        'کارخانجات کاشی و سرامیک حافظ',
        'پتروشیمی سرمایه گذاری ایرانیان',
        'کارخانه چینی ایران',
        'پتروشیمی لردگان',
        'کاشی بیستون',
        'پتروشیمی ممسنی',
        'کاشی پارس',
        'خاک طلایی توس',
        'کاشی تکسرام',
        'شهرک صنعتی پتروشیمی زنجان',
        'کاشی فیروزه مشهد',
        'صنايع پتروشيمي دهدشت',
        'کاشی کرد',
        'صنایع پتروشیمی تخت جمشید',
        'کاشی نیلو',
        'صنایع پتروشیمی زنجان',
        'کاشی و سرامیک سعدی',
        'گروه انبوه سازي، املاك و مستغلات',
        'کاشی و سرامیک سینا',
        'آ س پ',
        'گلسار فارس',
        'آذر توسعه مسکن',
        'گروه شركتهاي چند رشته اي صنعتي',
        'بين المللي توسعه ساختمان',
        'سرمايه گذاري غدير',
        'پارس مسکن خزر',
        'سرمایه گذاری گروه توسعه ملی(سرمایه گذاری بانک ملی ایران',
        'توسعه ساختمان خوارزمي',
        'گروه ساير وسايل حمل و نقل',
        'توسعه صنعت ساختمان غدیرخوزستان',
        'سرمايه گذاري اعتباري ايران',
        'زرین بنا پارسیان',
        'گروه ساخت راديو، تلويزيون و دستگاهها و وسايل ارتباطي',
        'ساختمان اصفهان',
        'آريا الكترونيك ايران',
        'ساختماني برج ناهيد',
        'پارس الكتريك',
        'سامان گستر اصفهان',
        'شهاب',
        'سرمايه گذاري توسعه شهري توس گستر',
        'صنايع مخابراتي راه دور ايران',
        'سرمايه گذاري توسعه وساختماني برج آوران',
        'فن آوران انیاک',
        'سرمايه گذاري ساختمان نوین',
        'كارخانجات صنعتي پيام',
        'سرمايه گذاري شاهد',
        'كارخانجات مخابراتي ايران',
        'سرمايه گذاري و توسعه خوزستان',
        'مرکز ماشینهای اداری ایران',
        'سرمایه گذاری مسکن تهران',
        'گروه محصولات چوبي',
        'سرمایه گذاری مسکن شمال شرق',
        'ایزوفام',
        'شهرسازی و خانه سازی باغ میشه',
        'توليد فيبر ايران',
        'صبا آرمه',
        'صنايع چوب خزر کاسپين',
        'طرح ساختمان پارسا',
        'نئوپان 22 بهمن',
        'عمران و توسعه شاهد',
        'سخت آژند',
        'گروه شرکت های مشاوره تبلیغاتی',
        'موسسه پویندگان توسعه پارس',
        # Source: https://en.wikipedia.org/wiki/List_of_companies_of_Iran
        'شرکت ملی نفت ایران',
        'معادن ایران',
        'سازمان نوسازی',
        'ایران خودرو',
        'امیدان تجارت کیش ',
        'سایپا',
        'مجتمع فولاد مبارکه',
        'بانک پارسیان',
        'بانک سامان',
        'بانک سپه',
        'صنایع پتروشیمی ایران',
        'بانک مسکن',
        'لایف برد پارسه',
        'صنایع پترو شیمی بو علی سینا',
        'فولاد خورستان',
        'ابر موتور',
        'سرمایه‌گذاری بانک ملی',
        'ایران خودرو دیزل',
        'توسعه صنعتی بوشهر',
        'بانک اقتصاد نوین',
        'شرکت زامیاد',
        'صنایع شیر ایران (پگاه)',
        'سرمایه‌گذاری غدیر',
        'ایمیدرو',
        'کارخانجات داروپخش',
        'سایپا دیزل',
        'بانک کارآفرین',
        'معدنی و صنعتی چادرملو',
        'ساخت تأسیسات دریایی ایران',
        'اتکا',
        'گسترش و نوسازی صنایع ایران',
        'تولی‌پرس',
        'هواپیمایی آسمان',
        'سازمان صنایع هوایی ایران',
        'مادیران',
        'پارس آنلاین',
        'شاتل',
        'شرکت مخابرات ایران',
        'ایرانسل',
        'راه‌آهن ایران',
        'هواپیمایی پیام',
        'متروی تهران',
        'شرکت ملی نفت‌کش ایران',
        'پالایش و پخش فراورده‌های نفتی ایران',
        'سازمان انرژی اتمی ایران',
        'صدا و سیما',
        'رجحان',
        'شرکت داده‌پردازی ایران',
        'گروه هتل‌های هما',
        'کیش اورینتال',
        'الک تیک',
    ]

    def company(self):
        return self.random_element(self.company_names)
